#!/bin/bash
#
# Usage: 
#
# cleanuptmp.sh /tmp/whatever
#
# /tmp must be a tmpfs on mountpoint none
#
LOKDIR=$1
VERBOSE=1
RET=0


[ $VERBOSE -gt 2 ] && echo "Directory: $LOKDIR"

# Exit when directory does not exist
if [ ! -d $LOKDIR ] ; then
    [ $VERBOSE -gt 0 ] && echo "$LOKDIR does not exist!" 
    exit $RET
fi


TMP_SIZE=`df $LOKDIR | grep none` 
[ $VERBOSE -gt 2 ] && echo "df $LOKDIR: $TMP_SIZE"
# grep makes sure that no drives are cleaned...

MAX_SIZE=`echo $TMP_SIZE | awk '{print $2+0}'`
CUR_SIZE=`echo $TMP_SIZE | awk '{print $3+0}'`
[ $VERBOSE -gt 1 ] && echo "MAX_SIZE=$MAX_SIZE, CUR_SIZE=$CUR_SIZE"


# Use max half of the overall size, TMP may be used by others, too.
if  [ $CUR_SIZE -gt $(($MAX_SIZE/2)) ] ; then
    [ $VERBOSE -gt 1 ] &&  echo "cleanup required" 
    ALLFILES=`ls -cr1 $LOKDIR`
    RMFILE=`echo $ALLFILES | awk '{print $1}'`
    # Others may use more than half of TMP, too.
    # ... and RMFILE may be empty!
    # So don't run into an endless loop!
    if [ -f $LOKDIR/$RMFILE ] ; then
        rm $LOKDIR/$RMFILE
        [ $VERBOSE -gt 0 ] && echo "Cleanup: rm $LOKDIR/$RMFILE"
        RET=1
    else 
        RET=0
    fi
else
    [ $VERBOSE -gt 2 ] && echo "OK"
    :
    
fi
[ $VERBOSE -gt 2 ] && echo "EXIT with $RET"

exit $RET
